

=========
Changelog
=========

Version 0.2.2 (2013-06-14)
--------------------------

 * Repair the source distribution to finally include all versioned files


Version 0.2 (2013-02-20)
------------------------

 * Made most fields optional
 * The video metadata file must now exist and validate upon adding the video.
 * Added a gallery view
 * Added a script to mass-add videos from the command line
 * Added a portlet to show selected videos
 * Bugfixes

Version 0.1.1i (2012-11-28)
---------------------------

Initial "real" release

